==> haskell-cmark-0.5.6-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
key: cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: a8957c403ec3ecdc2c7e0e636c334ead
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.1/site-local/cmark-0.5.6 /usr/
dynamic-library-dirs: /usr/lib /usr/
data-dir: /usr/share/i386-linux-ghc-8.2.1/cmark-0.5.6
hs-libraries: HScmark-0.5.6-3XSIcG4srepBYUTysvXhLF
extra-libraries:
    cmark
depends:
    base-4.10.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    bytestring-0.10.8.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-0.5.6-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
key: cmark-0.5.6-3XSIcG4srepBYUTysvXhLF
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: a8957c403ec3ecdc2c7e0e636c334ead
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.1/site-local/cmark-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cmark-0.5.6
hs-libraries: HScmark-0.5.6-3XSIcG4srepBYUTysvXhLF
extra-libraries:
    cmark
depends:
    base-4.10.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    bytestring-0.10.8.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
